@@ -4,6 +4,20 @@ import platform
 import sys
 import dataclasses
 
+#from versioning import __version__
+
+__version__ = "0.1.20"  # package version, also dynamically used by pyproject.toml
+__name__ = "cbl_tools"
+
+@dataclasses.dataclass
+class PackageInfo:
+    full_name: str
+    version: str
+
+
+def package_info() -> PackageInfo:
+    return PackageInfo(__name__, __version__)  # "1.0.1"
+
 
 @dataclasses.dataclass
 class PlatformInfo:
